@@ -39,7 +39,7 @@ class Live(JupyterMixin, RenderHook):
         console (Console, optional): Optional Console instance. Default will an internal Console instance writing to stdout.
         screen (bool, optional): Enable alternate screen mode. Defaults to False.
         auto_refresh (bool, optional): Enable auto refresh. If disabled, you will need to call `refresh()` or `update()` with refresh flag. Defaults to True
-        refresh_per_second (float, optional): Number of times per second to refresh the live display. Defaults to 1.
+        refresh_per_second (float, optional): Number of times per second to refresh the live display. Defaults to 4.
         transient (bool, optional): Clear the renderable on exit (has no effect when screen=True). Defaults to False.
         redirect_stdout (bool, optional): Enable redirection of stdout, so ``print`` may be used. Defaults to True.
         redirect_stderr (bool, optional): Enable redirection of stderr. Defaults to True.
@@ -86,7 +86,11 @@ class Live(JupyterMixin, RenderHook):
         self._live_render = LiveRender(
             self.get_renderable(), vertical_overflow=vertical_overflow
         )
-        # cant store just clear_control as the live_render shape is lazily computed on render
+
+    @property
+    def is_started(self) -> bool:
+        """Check if live display has been started."""
+        return self._started
 
     def get_renderable(self) -> RenderableType:
         renderable = (
@@ -205,17 +209,17 @@ class Live(JupyterMixin, RenderHook):
 
     def refresh(self) -> None:
         """Update the display of the Live Render."""
-        self._live_render.set_renderable(self.renderable)
-        if self.console.is_jupyter:  # pragma: no cover
-            try:
-                from IPython.display import display
-                from ipywidgets import Output
-            except ImportError:
-                import warnings
+        with self._lock:
+            self._live_render.set_renderable(self.renderable)
+            if self.console.is_jupyter:  # pragma: no cover
+                try:
+                    from IPython.display import display
+                    from ipywidgets import Output
+                except ImportError:
+                    import warnings
 
-                warnings.warn('install "ipywidgets" for Jupyter support')
-            else:
-                with self._lock:
+                    warnings.warn('install "ipywidgets" for Jupyter support')
+                else:
                     if self.ipy_widget is None:
                         self.ipy_widget = Output()
                         display(self.ipy_widget)
@@ -223,14 +227,14 @@ class Live(JupyterMixin, RenderHook):
                     with self.ipy_widget:
                         self.ipy_widget.clear_output(wait=True)
                         self.console.print(self._live_render.renderable)
-        elif self.console.is_terminal and not self.console.is_dumb_terminal:
-            with self._lock, self.console:
-                self.console.print(Control(""))
-        elif (
-            not self._started and not self.transient
-        ):  # if it is finished allow files or dumb-terminals to see final result
-            with self.console:
-                self.console.print(Control(""))
+            elif self.console.is_terminal and not self.console.is_dumb_terminal:
+                with self.console:
+                    self.console.print(Control())
+            elif (
+                not self._started and not self.transient
+            ):  # if it is finished allow files or dumb-terminals to see final result
+                with self.console:
+                    self.console.print(Control())
 
     def process_renderables(
         self, renderables: List[ConsoleRenderable]
