@@ -78,7 +78,7 @@ class Tree(JupyterMixin):
 
         get_style = console.get_style
         null_style = Style.null()
-        guide_style = get_style(self.guide_style) or null_style
+        guide_style = get_style(self.guide_style, default="") or null_style
         SPACE, CONTINUE, FORK, END = range(4)
 
         ASCII_GUIDES = ("    ", "|   ", "+-- ", "`-- ")
@@ -130,6 +130,7 @@ class Tree(JupyterMixin):
                     width=options.max_width
                     - sum(level.cell_length for level in prefix),
                     highlight=self.highlight,
+                    height=None,
                 ),
             )
             for first, line in loop_first(renderable_lines):
@@ -157,7 +158,9 @@ class Tree(JupyterMixin):
                 guide_style_stack.push(get_style(node.guide_style))
                 push(iter(loop_last(node.children)))
 
-    def __rich_measure__(self, console: "Console", max_width: int) -> "Measurement":
+    def __rich_measure__(
+        self, console: "Console", options: "ConsoleOptions"
+    ) -> "Measurement":
         stack: List[Iterator[Tree]] = [iter([self])]
         pop = stack.pop
         push = stack.append
@@ -173,7 +176,7 @@ class Tree(JupyterMixin):
                 level -= 1
                 continue
             push(iter_tree)
-            min_measure, max_measure = measure(console, tree.label, max_width)
+            min_measure, max_measure = measure(console, options, tree.label)
             indent = level * 4
             minimum = max(min_measure + indent, minimum)
             maximum = max(max_measure + indent, maximum)
